==> leveldb-server-0.92.tar.gz: leveldb-server-0.92/leveldbserver/__init__.py <==
__author__ = 'ardevelop'

import sys
import ujson
import leveldb
import tornado.web
import tornado.ioloop


class Application(tornado.web.Application):
    def __init__(self, path):
        self.db = leveldb.LevelDB(path)
        self.get = 0
        self.miss = 0
        self.put = 0
        super(Application, self).__init__(
            [("/", MultipleRequestHandler), ("/stats", StatsRequestHandler), ("/(.+)", KeyRequestHandler)],
            auto_etag=False)


class KeyRequestHandler(tornado.web.RequestHandler):
    def get(self, key):
        app = self.application
        try:
            self.finish(app.db.Get(key))
            app.get += 1
            print "get", key
        except KeyError:
            app.miss += 1
            print "miss", key
            raise tornado.web.HTTPError(404)

    def put(self, key):
        value = self.request.body
        if value:
            app = self.application
            app.db.Put(key, value)
            app.put += 1
            print "put", key

    def write_error(self, status_code, **kwargs):
        self.finish()


class MultipleRequestHandler(tornado.web.RequestHandler):
    def get(self):
        app = self.application
        keys = self.get_arguments("key")
        result = []
        for key in keys:
            try:
                result.append(app.db.Get(key))
                app.get += 1
                print key
            except KeyError:
                result.append(None)
                app.miss += 1
                print "miss", key

        try:
            self.finish(ujson.dumps(result))
        except ValueError:
            sys.stderr.write("Unable to serialize result \"%s\" for request \"%s\"" % (result, keys))
            raise tornado.web.HTTPError(400)

    def put(self):
        app = self.application
        try:
            mapping = ujson.loads(self.request.body)
            for key, value in mapping.iteritems():
                app.db.Put(key, value)
                app.put += 1
                print "put", key

        except (ValueError, AttributeError):
            raise tornado.web.HTTPError(400)

    def write_error(self, status_code, **kwargs):
        self.finish()


class StatsRequestHandler(tornado.web.RequestHandler):
    def get(self):
        app = self.application
        self.finish("get: %s, put: %s, miss: %s" % (app.get, app.put, app.miss))


def run():
    import sys
    import argparse
    import ardaemon

    parser = argparse.ArgumentParser(description="leveldb server")
    parser.add_argument("-i", metavar="address", type=str, default="0.0.0.0", dest="interface",
                        help="listening interface")
    parser.add_argument("-p", metavar="port", type=int, default=6521, dest="port", help="listening port")
    parser.add_argument("-d", metavar="path", type=str, dest="path", default="/tmp/leveldb", help="database location")

    with ardaemon.Daemon(name="leveldb", parser=parser, stdout=sys.stdout, stderr=sys.stderr) as daemon:
        import tornado.httpserver
        import tornado.ioloop

        app = Application(daemon.args.path)
        srv = tornado.httpserver.HTTPServer(app)
        srv.bind(daemon.args.port, daemon.args.interface)
        srv.start()
        tornado.ioloop.IOLoop.instance().start()


if "__main__" == __name__:
    run()

==> leveldb-server-1.0.tar.gz: leveldb-server-1.0/leveldbserver/__init__.py <==
__author__ = 'ardevelop'

import ujson
import leveldb
import tornado.web
import tornado.ioloop


class Application(tornado.web.Application):
    def __init__(self, path):
        self.db = leveldb.LevelDB(path)
        self.get = 0
        self.miss = 0
        self.put = 0
        super(Application, self).__init__(
            [("/", MultipleRequestHandler), ("/stats", StatsRequestHandler), ("/(.+)", KeyRequestHandler)],
            auto_etag=False)

    def log_request(self, handler):
        pass


class KeyRequestHandler(tornado.web.RequestHandler):
    def get(self, key):
        app = self.application
        try:
            self.finish(app.db.Get(key))
            app.get += 1
            print "get", key
        except KeyError:
            app.miss += 1
            print "miss", key
            raise tornado.web.HTTPError(404)

    def put(self, key):
        value = self.request.body
        if value:
            app = self.application
            app.db.Put(key, value)
            app.put += 1
            print "put", key

    def write_error(self, status_code, **kwargs):
        self.finish()


class MultipleRequestHandler(tornado.web.RequestHandler):
    def get(self):
        app = self.application
        keys = self.get_arguments("key")
        result = []
        for key in keys:
            try:
                result.append(app.db.Get(key))
                app.get += 1
                print key
            except KeyError:
                result.append(None)
                app.miss += 1
                print "miss", key

        try:
            self.finish(ujson.dumps(result))
        except ValueError:
            raise tornado.web.HTTPError(400)

    def put(self):
        app = self.application
        try:
            mapping = ujson.loads(self.request.body)
        except (ValueError, AttributeError):
            raise tornado.web.HTTPError(400)

        for key, value in mapping.iteritems():
            app.db.Put(key, value)
            app.put += 1
            print "put", key

    def write_error(self, status_code, **kwargs):
        self.finish()


class StatsRequestHandler(tornado.web.RequestHandler):
    def get(self):
        app = self.application
        self.finish("get: %s, put: %s, miss: %s" % (app.get, app.put, app.miss))


def run():
    import sys
    import argparse
    import ardaemon

    parser = argparse.ArgumentParser(description="leveldb server")
    parser.add_argument("-i", metavar="address", type=str, default="0.0.0.0", dest="interface",
                        help="listening interface")
    parser.add_argument("-p", metavar="port", type=int, default=6521, dest="port", help="listening port")
    parser.add_argument("-d", metavar="path", type=str, dest="path", default="/tmp/leveldb", help="database location")

    with ardaemon.Daemon(name="leveldb", parser=parser, stdout=sys.stdout, stderr=sys.stderr) as daemon:
        import tornado.httpserver
        import tornado.ioloop

        app = Application(daemon.args.path)
        srv = tornado.httpserver.HTTPServer(app)
        srv.bind(daemon.args.port, daemon.args.interface)
        srv.start()
        tornado.ioloop.IOLoop.instance().start()


if "__main__" == __name__:
    run()
